@@ -10,11 +10,11 @@
 #ifndef FIR
 #if (defined(__APPLE__) && !defined(INT128)) || defined(__FreeBSD__)
 #include <libintl.h>
-#ifndef _LIBINTL_H
+#if !defined POCKETCAS && !defined _LIBINTL_H
 #define _LIBINTL_H      1
 #endif
 #endif
-#endif
+#endif // ndef FIR
 
 #ifdef HAVE_GETTEXT
 #include <libintl.h>
@@ -23,7 +23,7 @@
 #ifndef _LIBINTL_H
 #define _LIBINTL_H      1
 #define __LIBINTL_H_DEFINED__ // Pour NetBSD 
-#if defined GIAC_HAS_STO_38 || defined EMCC
+#if defined GIAC_HAS_STO_38 || defined EMCC || defined KHICAS
 const char * gettext(const char * s); // in aspen.cc or opengl.cc
 #else
 inline const char * gettext(const char * s) { return s; };
